
.. |GCode| replace:: :py:class:`~mmgroup.GCode`
.. |PLoop| replace:: :py:class:`~mmgroup.PLoop`
.. |GcVector| replace:: :py:class:`~mmgroup.GcVector`
.. |SubOctad| replace:: :py:class:`~mmgroup.SubOctad`
.. |Cocode| replace:: :py:class:`~mmgroup.Cocode`
.. |Parity| replace:: :py:class:`~mmgroup.Parity`
.. |AutPL| replace:: :py:class:`~mmgroup.AutPL`
.. |XLeech2| replace:: :py:class:`~mmgroup.XLeech2`
.. |MMGroup| replace:: :py:class:`~mmgroup.MMGroup`
.. |MM| replace:: :py:class:`~mmgroup.MM`
.. |MMSpace| replace:: :py:class:`~mmgroup.MMSpace`
.. |MMVector| replace:: :py:class:`~mmgroup.MMVector`

